@@ -39,12 +39,17 @@ Common classes used by both Flink DataStream API and Table API:
     - :class:`SerializationSchema`:
       Base class to describes how to turn a data object into a different serialized representation.
       Most data sinks (for example Apache Kafka) require the data to be handed to them in a specific
-      format (for example as byte strings). See :class:`JsonRowSerializationSchema`,
-      :class:`JsonRowDeserializationSchema`, :class:`CsvRowSerializationSchema`,
-      :class:`CsvRowDeserializationSchema`, :class:`AvroRowSerializationSchema`,
-      :class:`AvroRowDeserializationSchema` and :class:`SimpleStringSchema` for more details.
+      format (for example as byte strings). See
+      :class:`~pyflink.datastream.formats.json.JsonRowSerializationSchema`,
+      :class:`~pyflink.datastream.formats.json.JsonRowDeserializationSchema`,
+      :class:`~pyflink.datastream.formats.csv.CsvRowSerializationSchema`,
+      :class:`~pyflink.datastream.formats.csv.CsvRowDeserializationSchema`,
+      :class:`~pyflink.datastream.formats.avro.AvroRowSerializationSchema`,
+      :class:`~pyflink.datastream.formats.avro.AvroRowDeserializationSchema` and
+      :class:`~SimpleStringSchema` for more details.
 """
 from pyflink.common.completable_future import CompletableFuture
+from pyflink.common.config_options import ConfigOption, ConfigOptions
 from pyflink.common.configuration import Configuration
 from pyflink.common.execution_config import ExecutionConfig
 from pyflink.common.execution_mode import ExecutionMode
@@ -55,17 +60,18 @@ from pyflink.common.job_id import JobID
 from pyflink.common.job_status import JobStatus
 from pyflink.common.restart_strategy import RestartStrategies, RestartStrategyConfiguration
 from pyflink.common.serialization import SerializationSchema, DeserializationSchema, \
-    SimpleStringSchema, JsonRowSerializationSchema, JsonRowDeserializationSchema, \
-    CsvRowSerializationSchema, CsvRowDeserializationSchema, AvroRowSerializationSchema, \
-    AvroRowDeserializationSchema, Encoder
+    SimpleStringSchema, Encoder
 from pyflink.common.serializer import TypeSerializer
 from pyflink.common.typeinfo import Types, TypeInformation
 from pyflink.common.types import Row, RowKind
-from pyflink.common.time import Duration
-from pyflink.common.watermark_strategy import WatermarkStrategy
+from pyflink.common.time import Duration, Instant, Time
+from pyflink.common.watermark_strategy import WatermarkStrategy, \
+    AssignerWithPeriodicWatermarksWrapper
 
 __all__ = [
     'Configuration',
+    'ConfigOption',
+    'ConfigOptions',
     'ExecutionConfig',
     "TypeInformation",
     "TypeSerializer",
@@ -73,12 +79,6 @@ __all__ = [
     'SerializationSchema',
     'DeserializationSchema',
     'SimpleStringSchema',
-    'JsonRowSerializationSchema',
-    'JsonRowDeserializationSchema',
-    'CsvRowSerializationSchema',
-    'CsvRowDeserializationSchema',
-    'AvroRowSerializationSchema',
-    'AvroRowDeserializationSchema',
     'Encoder',
     'CompletableFuture',
     'ExecutionMode',
@@ -92,5 +92,35 @@ __all__ = [
     "Row",
     "RowKind",
     "WatermarkStrategy",
-    "Duration"
+    "Duration",
+    "Instant",
+    "Time",
+    "AssignerWithPeriodicWatermarksWrapper"
 ]
+
+
+def _install():
+    from pyflink import common
+
+    # json
+    from pyflink.datastream.formats.json import JsonRowDeserializationSchema
+    from pyflink.datastream.formats.json import JsonRowSerializationSchema
+    setattr(common, 'JsonRowDeserializationSchema', JsonRowDeserializationSchema)
+    setattr(common, 'JsonRowSerializationSchema', JsonRowSerializationSchema)
+
+    # csv
+    from pyflink.datastream.formats.csv import CsvRowDeserializationSchema
+    from pyflink.datastream.formats.csv import CsvRowSerializationSchema
+    setattr(common, 'CsvRowDeserializationSchema', CsvRowDeserializationSchema)
+    setattr(common, 'CsvRowSerializationSchema', CsvRowSerializationSchema)
+
+    # avro
+    from pyflink.datastream.formats.avro import AvroRowDeserializationSchema
+    from pyflink.datastream.formats.avro import AvroRowSerializationSchema
+    setattr(common, 'AvroRowDeserializationSchema', AvroRowDeserializationSchema)
+    setattr(common, 'AvroRowSerializationSchema', AvroRowSerializationSchema)
+
+
+# for backward compatibility
+_install()
+del _install
