@@ -20,6 +20,7 @@ from enum import Enum
 from typing import Optional
 
 from pyflink.common import Duration
+from pyflink.datastream.externalized_checkpoint_retention import ExternalizedCheckpointRetention
 from pyflink.datastream.checkpoint_storage import CheckpointStorage, _from_j_checkpoint_storage
 from pyflink.datastream.checkpointing_mode import CheckpointingMode
 from pyflink.java_gateway import get_gateway
@@ -76,7 +77,7 @@ class CheckpointConfig(object):
         :return: The :class:`CheckpointingMode`.
         """
         return CheckpointingMode._from_j_checkpointing_mode(
-            self._j_checkpoint_config.getCheckpointingMode())
+            self._j_checkpoint_config.getCheckpointingConsistencyMode())
 
     def set_checkpointing_mode(self, checkpointing_mode: CheckpointingMode) -> 'CheckpointConfig':
         """
@@ -90,7 +91,7 @@ class CheckpointConfig(object):
 
         :param checkpointing_mode: The :class:`CheckpointingMode`.
         """
-        self._j_checkpoint_config.setCheckpointingMode(
+        self._j_checkpoint_config.setCheckpointingConsistencyMode(
             CheckpointingMode._to_j_checkpointing_mode(checkpointing_mode))
         return self
 
@@ -313,11 +314,49 @@ class CheckpointConfig(object):
                              :data:`ExternalizedCheckpointCleanup.DELETE_ON_CANCELLATION`,
                              :data:`ExternalizedCheckpointCleanup.RETAIN_ON_CANCELLATION` or
                              :data:`ExternalizedCheckpointCleanup.NO_EXTERNALIZED_CHECKPOINTS`
+
+        note:: Deprecated. Use :func:`set_externalized_checkpoint_retention` instead.
         """
         self._j_checkpoint_config.setExternalizedCheckpointCleanup(
             ExternalizedCheckpointCleanup._to_j_externalized_checkpoint_cleanup(cleanup_mode))
         return self
 
+    def set_externalized_checkpoint_retention(
+            self,
+            retention_mode: 'ExternalizedCheckpointRetention') -> 'CheckpointConfig':
+        """
+        Sets the mode for externalized checkpoint clean-up. Externalized checkpoints will be enabled
+        automatically unless the mode is set to
+        :data:`ExternalizedCheckpointRetention.NO_EXTERNALIZED_CHECKPOINTS`.
+
+        Externalized checkpoints write their meta data out to persistent storage and are **not**
+        automatically cleaned up when the owning job fails or is suspended (terminating with job
+        status ``FAILED`` or ``SUSPENDED``). In this case, you have to manually clean up the
+        checkpoint state, both the meta data and actual program state.
+
+        The :class:`ExternalizedCheckpointRetention` mode defines how an externalized checkpoint
+        should be cleaned up on job cancellation. If you choose to retain externalized checkpoints
+        on cancellation you have to handle checkpoint clean-up manually when you cancel the job as
+        well (terminating with job status ``CANCELED``).
+
+        The target directory for externalized checkpoints is configured via
+        ``org.apache.flink.configuration.CheckpointingOptions#CHECKPOINTS_DIRECTORY``.
+
+        Example:
+        ::
+
+            >>> config.set_externalized_checkpoint_retention(
+            ...     ExternalizedCheckpointRetention.RETAIN_ON_CANCELLATION)
+
+        :param retention_mode: Externalized checkpoint clean-up behaviour, the mode could be
+                             :data:`ExternalizedCheckpointRetention.DELETE_ON_CANCELLATION`,
+                             :data:`ExternalizedCheckpointRetention.RETAIN_ON_CANCELLATION` or
+                             :data:`ExternalizedCheckpointRetention.NO_EXTERNALIZED_CHECKPOINTS`
+        """
+        self._j_checkpoint_config.setExternalizedCheckpointRetention(
+            ExternalizedCheckpointRetention._to_j_externalized_checkpoint_retention(retention_mode))
+        return self
+
     def is_externalized_checkpoints_enabled(self) -> bool:
         """
         Returns whether checkpoints should be persisted externally.
@@ -332,6 +371,8 @@ class CheckpointConfig(object):
 
         :return: The cleanup behaviour for externalized checkpoints or ``None`` if none is
                  configured.
+
+        note:: Deprecated. Use :func:`get_externalized_checkpoint_retention` instead.
         """
         cleanup_mode = self._j_checkpoint_config.getExternalizedCheckpointCleanup()
         if cleanup_mode is None:
@@ -340,6 +381,20 @@ class CheckpointConfig(object):
             return ExternalizedCheckpointCleanup._from_j_externalized_checkpoint_cleanup(
                 cleanup_mode)
 
+    def get_externalized_checkpoint_retention(self) -> Optional['ExternalizedCheckpointRetention']:
+        """
+        Returns the cleanup behaviour for externalized checkpoints.
+
+        :return: The cleanup behaviour for externalized checkpoints or ``None`` if none is
+                 configured.
+        """
+        retention_mode = self._j_checkpoint_config.getExternalizedCheckpointRetention()
+        if retention_mode is None:
+            return None
+        else:
+            return ExternalizedCheckpointRetention._from_j_externalized_checkpoint_retention(
+                retention_mode)
+
     def is_unaligned_checkpoints_enabled(self) -> bool:
         """
         Returns whether unaligned checkpoints are enabled.
@@ -516,6 +571,9 @@ class ExternalizedCheckpointCleanup(Enum):
     :data:`NO_EXTERNALIZED_CHECKPOINTS`:
 
     Externalized checkpoints are disabled completely.
+
+    note:: Deprecated.  Please use
+    pyflink.datastream.externalized_checkpoint_retention.ExternalizedCheckpointRetention instead.
     """
 
     DELETE_ON_CANCELLATION = 0
